package com.tencent.liteav.demo.player

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.*
import androidx.appcompat.app.AppCompatActivity
import com.tencent.liteav.demo.player.databinding.FragmentMenuBinding
import com.tencent.liteav.demo.player.http.CourseApi
import com.tencent.liteav.demo.player.http.HttpManager
import com.tencent.liteav.demo.player.menu.PlayerTimer
import com.tencent.liteav.demo.player.util.ModelProvider
import kotlinx.coroutines.*
import kotlin.concurrent.thread

class PlayerMenu : AppCompatActivity(), View.OnClickListener, CoroutineScope by MainScope() {
    private var _viewBinding: FragmentMenuBinding? = null
    private val viewBinding get() = _viewBinding!!

    private val imageBack get() = viewBinding.menuItemBack
    private val imageShare get() = viewBinding.menuItemShare
    private val imageFavorite get() = viewBinding.menuItemFavorite
    private val imageCast get() = viewBinding.menuItemCast
    private val imageTimer get() = viewBinding.menuItemTimer

    private lateinit var courseId: String

    private val api: CourseApi = HttpManager.create()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        _viewBinding = FragmentMenuBinding.inflate(layoutInflater)
        setContentView(viewBinding.root)

        window.setLayout(
            WindowManager.LayoutParams.MATCH_PARENT,
            WindowManager.LayoutParams.MATCH_PARENT
        )

        courseId = intent?.getStringExtra(KEY_COURSE_ID) ?: "0"

        imageBack.setOnClickListener(this)

        imageShare.setOnClickListener(this)
        imageShare.setIcon(R.mipmap.item_share)
        imageShare.setTitle("分享")

        imageFavorite.setOnClickListener(this)
        imageFavorite.setIcon(R.mipmap.item_favorite)
        imageFavorite.setTitle("收藏")

        imageCast.setOnClickListener(this)
        imageCast.setIcon(R.mipmap.item_cast)
        imageCast.setTitle("投屏")

        imageTimer.setOnClickListener(this)
        imageTimer.setIcon(R.mipmap.item_timer)
        imageTimer.setTitle("定时关闭")

        setFavorite()
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.menu_item_back -> {
                finish()
            }
            R.id.menu_item_cast -> {
                PlayerVerify.start(this@PlayerMenu, REQUEST_CODE_CAST)
            }
            R.id.menu_item_favorite -> {
                launch(Dispatchers.IO) {
                    val result = api.favoriteCourse(
                        mapOf(
                            "aiCourseSkuId" to ModelProvider.courseId,
                            "aiCourseSpuId" to ModelProvider.cccccc.aiCourseSpuId,
                        )
                    )

                    withContext(Dispatchers.Main) {
                        ModelProvider.cccccc.isCollect = result.data ?: 0
                        setFavorite()
                    }
                }
            }
            R.id.menu_item_share -> {
                PlayerVerify.start(this@PlayerMenu, REQUEST_CODE_SHARE)
            }
            R.id.menu_item_timer -> {
                PlayerVerify.start(this@PlayerMenu, REQUEST_CODE_TIMER)
            }
        }
    }

    private fun setFavorite() {
        if (ModelProvider.cccccc.isCollect == 1) {
            imageFavorite.setIcon(R.mipmap.item_favorited)
            imageFavorite.setTitle("已收藏")
            imageFavorite.setTextColor(Color.parseColor("#FFFF9E3E"))
        } else {
            imageFavorite.setIcon(R.mipmap.item_favorite)
            imageFavorite.setTitle("收藏")
            imageFavorite.setTextColor(Color.parseColor("#FF666666"))
        }
    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == RESULT_OK) {
            when (requestCode) {
                REQUEST_CODE_SHARE -> {
                    val intent = Intent(this, PlayerShare::class.java)
                    startActivity(intent)
                    finish()
                }
                REQUEST_CODE_CAST -> {
                    val intent = Intent(this, PlayerCast::class.java)
                    startActivity(intent)
                    finish()
                }
                REQUEST_CODE_TIMER -> {
                    val intent = Intent(this, PlayerTimer::class.java)
                    startActivity(intent)
                    finish()
                }
            }
        }
    }

    companion object {
        const val KEY_COURSE_ID = "course_id"

        const val REQUEST_CODE_SHARE = 901
        const val REQUEST_CODE_CAST = 902
        const val REQUEST_CODE_TIMER = 903

        fun start(context: Context, courseId: String) {
            val intent = Intent(context, PlayerMenu::class.java).apply {
                putExtra(KEY_COURSE_ID, courseId)
            }
            context.startActivity(intent)
        }
    }
}