package com.tencent.liteav.demo.player.menu

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.res.ResourcesCompat
import com.tencent.liteav.demo.player.PlayerWheel
import com.tencent.liteav.demo.player.R
import com.tencent.liteav.demo.player.databinding.FragmentTimerBinding
import com.tencent.liteav.demo.player.util.TimingUtil
import com.tencent.liteav.demo.superplayer.database.entity.CountDown
import com.tencent.liteav.demo.superplayer.util.TimersUtil

class PlayerTimer : AppCompatActivity(), View.OnClickListener {
    private var _viewBinding: FragmentTimerBinding? = null
    private val viewBinding get() = _viewBinding!!

    private val back get() = viewBinding.menuItemBack

    private val none get() = viewBinding.timerItemNone

    private val ep1 get() = viewBinding.timerItemEpisodeOne
    private val ep2 get() = viewBinding.timerItemEpisodeTwo
    private val ep3 get() = viewBinding.timerItemEpisodeThree

    private val dt10 get() = viewBinding.timerItemDuration10
    private val dt20 get() = viewBinding.timerItemDuration20
    private val dt30 get() = viewBinding.timerItemDuration30
    private val custom get() = viewBinding.timerItemDurationCustom

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        _viewBinding = FragmentTimerBinding.inflate(layoutInflater)
        setContentView(viewBinding.root)

        window.setLayout(-1, -1)

        back.setOnClickListener(this)
        none.setOnClickListener(this)
        ep1.setOnClickListener(this)
        ep2.setOnClickListener(this)
        ep3.setOnClickListener(this)
        dt10.setOnClickListener(this)
        dt20.setOnClickListener(this)
        dt30.setOnClickListener(this)
        custom.setOnClickListener(this)
        
        when(TimingUtil.index){
            0->{
                none.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                none.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            1->{
                ep1.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                ep1.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            2->{
                ep2.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                ep2.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            3->{
                ep3.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                ep3.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            4->{
                dt10.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                dt10.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            5->{
                dt20.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                dt20.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            6->{
                dt30.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                dt30.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
            7->{
                custom.background = ResourcesCompat.getDrawable(resources,R.drawable.menu_timer_option_decoration,null)
                custom.setTextColor(Color.parseColor("#FFFFFFFF"))
            }
        }
    }

    override fun onClick(v: View) {
        when (v.id) {
            back.id -> {
                finish()
            }
            none.id -> {
                TimersUtil.sendNewTimer(0, 0)
                TimingUtil.toast(this,0, 0)
            }
            ep1.id -> {
                TimersUtil.sendNewTimer(1, 1)
                TimingUtil.toast(this,1, 1)
            }
            ep2.id -> {
                TimersUtil.sendNewTimer(1, 2)
                TimingUtil.toast(this,1, 2)
            }
            ep3.id -> {
                TimersUtil.sendNewTimer(1, 3)
                TimingUtil.toast(this,1, 3)
            }
            dt10.id -> {
                TimersUtil.sendNewTimer(2, 10 * 60)
                TimingUtil.toast(this,2, 10*60)
            }
            dt20.id -> {
                TimersUtil.sendNewTimer(2, 20 * 60)
                TimingUtil.toast(this,2, 20*60)
            }
            dt30.id -> {
                TimersUtil.sendNewTimer(2, 30 * 60)
                TimingUtil.toast(this,2, 30*60)
            }
            custom.id -> {
                val intent = Intent(this@PlayerTimer, PlayerWheel::class.java)
                startActivity(intent)
            }
        }

        finish()
    }
}